@@ -4,27 +4,17 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 use Test::More;
 
-sub do_test {
-	my %MODULES = (
-		'Test::Distribution'	=> '2.00',
+sub _load_prereqs {
+	return (
+		'Test::Distribution'	=> '2.00 ()',
 	);
+}
 
-	while (my ($module, $version) = each %MODULES) {
-		eval "use $module $version ()";	## no critic ( ProhibitStringyEval )
-		next unless $@;
-
-		if ( $ENV{RELEASE_TESTING} ) {
-			die 'Could not load release-testing module ' . $module . " -> $@";
-		} else {
-			plan skip_all => $module . ' not available for testing';
-		}
-	}
-
-	# Run the test!
+sub do_test {
 	# we ignore podcover because we already have a plugin for it...
 	Test::Distribution->import( not => 'podcover', distversion => 1 );
 
